@@ -19,7 +19,6 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 #include "greeterapp.h"
-#include "authenticator.h"
 #include "kscreensaversettingsbase.h"
 #include "lnf_integration.h"
 #include "noaccessnetworkaccessmanagerfactory.h"
@@ -33,10 +32,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 // KDE
 #include <KAuthorized>
+#include <KConfigPropertyMap>
 #include <KCrash>
-#include <KDeclarative/ConfigPropertyMap>
 #include <KDeclarative/KQuickAddons/QuickViewSharedEngine>
 #include <KDeclarative/QmlObjectSharedEngine>
+#include <KLocalizedContext>
 #include <KWindowSystem>
 #include <kdeclarative/kdeclarative.h>
 
@@ -65,7 +65,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QQuickItem>
 #include <QQuickView>
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
 // Wayland
 #include <wayland-client.h>
 #include <wayland-ksld-client-protocol.h>
@@ -76,6 +80,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
 #include <xcb/xcb.h>
 
+#include "pamauthenticator.h"
+
 // this is usable to fake a "screensaver" installation for testing
 // *must* be "0" for every public commit!
 #define TEST_SCREENSAVER 0
@@ -98,7 +104,11 @@ Q_CONSTRUCTOR_FUNCTION(disableDrKonqi)
 class FocusOutEventFilter : public QAbstractNativeEventFilter
 {
 public:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     bool nativeEventFilter(const QByteArray &eventType, void *message, long int *result) override
+#else
+    bool nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result) override
+#endif
     {
         Q_UNUSED(result)
         if (qstrcmp(eventType, "xcb_generic_event_t") != 0) {
@@ -126,9 +136,17 @@ UnlockApp::UnlockApp(int &argc, char **argv)
     , m_wallpaperIntegration(new WallpaperIntegration(this))
     , m_lnfIntegration(new LnFIntegration(this))
 {
-    m_authenticator = createAuthenticator();
+    m_authenticator = new PamAuthenticator("kde", KUser().loginName(), this);
     // It's a queued connection to give the QML part time to eventually execute code connected to Authenticator::succeeded if any
-    connect(m_authenticator, &Authenticator::succeeded, this, &QCoreApplication::quit, Qt::QueuedConnection);
+    connect(
+        m_authenticator,
+        &PamAuthenticator::succeeded,
+        this,
+        []() {
+            qApp->quit();
+        },
+        Qt::QueuedConnection);
+
     initialize();
 
     if (QX11Info::isPlatformX11()) {
@@ -160,11 +178,6 @@ UnlockApp::~UnlockApp()
     }
 }
 
-Authenticator *UnlockApp::createAuthenticator()
-{
-    return new Authenticator(AuthenticationMode::Direct, this);
-}
-
 void UnlockApp::initialize()
 {
     // set up the request ignore timeout, so that multiple requests to sleep/suspend/shutdown
@@ -183,6 +196,11 @@ void UnlockApp::initialize()
     if (!KScreenSaverSettingsBase::theme().isEmpty()) {
         package.setPath(KScreenSaverSettingsBase::theme());
     }
+    QString plasmaApiVersion = package.metadata().value("X-Plasma-APIVersion", QStringLiteral("1"));
+    if (plasmaApiVersion.toInt() <= 1) {
+        qCWarning(KSCREENLOCKER_GREET) << "Lockscreen QML outdated, falling back to default";
+        package.setPath(QString());
+    }
 
     m_mainQmlPath = package.fileUrl("lockscreenmainscript");
 
@@ -302,9 +320,8 @@ KQuickAddons::QuickViewSharedEngine *UnlockApp::createViewForScreen(QScreen *scr
     });
 
     // first create KDeclarative, to be sure that it created a KIO Network Factory
-    KDeclarative::KDeclarative declarative;
-    declarative.setDeclarativeEngine(view->engine());
-    declarative.setupBindings();
+    KDeclarative::KDeclarative::setupEngine(view->engine());
+    view->engine()->rootContext()->setContextObject(new KLocalizedContext(view->engine()));
 
     if (!m_testing) {
         if (QX11Info::isPlatformX11()) {
@@ -380,6 +397,7 @@ KQuickAddons::QuickViewSharedEngine *UnlockApp::createViewForScreen(QScreen *scr
         if (auto layerShellWindow = LayerShellQt::Window::get(view)) {
             layerShellWindow->setExclusiveZone(-1);
             layerShellWindow->setLayer(LayerShellQt::Window::LayerOverlay);
+            layerShellWindow->setDesiredOutput(screen);
         }
     }
 
@@ -469,7 +487,7 @@ void UnlockApp::suspendToRam()
     m_ignoreRequests = true;
     m_resetRequestIgnoreTimer->start();
 
-    org_kde_ksld_suspendSystem(m_ksldInterface);
+    PowerManagement::instance()->suspend();
 }
 
 void UnlockApp::suspendToDisk()
@@ -481,7 +499,7 @@ void UnlockApp::suspendToDisk()
     m_ignoreRequests = true;
     m_resetRequestIgnoreTimer->start();
 
-    org_kde_ksld_hibernateSystem(m_ksldInterface);
+    PowerManagement::instance()->hibernate();
 }
 
 void UnlockApp::setTesting(bool enable)
@@ -706,3 +724,5 @@ void UnlockApp::updateCanHibernate()
 }
 
 } // namespace
+
+#include "greeterapp.moc"
