@@ -17,7 +17,6 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *********************************************************************/
 #include <KLocalizedString>
-#include <KQuickAddons/QtQuickSettings>
 
 #include <QCommandLineParser>
 #include <QDateTime>
@@ -100,8 +99,6 @@ int main(int argc, char *argv[])
     QCoreApplication::setApplicationVersion(QStringLiteral("0.1"));
     QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
 
-    KQuickAddons::QtQuickSettings::init();
-
     // disable session management for the greeter
     auto disableSessionManagement = [](QSessionManager &sm) {
         sm.setRestartHint(QSessionManager::RestartNever);
@@ -185,7 +182,7 @@ int main(int argc, char *argv[])
 
     // This allow ksmserver to know when the application has actually finished setting itself up.
     // Crucial for blocking until it is ready, ensuring locking happens before sleep, e.g.
-    std::cout << "Locked at " << QDateTime::currentDateTime().toTime_t() << std::endl;
+    std::cout << "Locked at " << QDateTime::currentDateTime().toSecsSinceEpoch() << std::endl;
 
     struct sigaction sa;
     sa.sa_handler = signalHandler;
